==> dojo-1.9.4.tgz: package/cldr/nls/sv/japanese.js <==
define(
//begin v1.x content
{
	"field-second": "sekund",
	"field-year-relative+-1": "i fjol",
	"field-week": "vecka",
	"field-month-relative+-1": "förra månaden",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i förrgår",
	"field-year": "år",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka",
	"field-minute": "minut",
	"field-week-relative+-1": "förra veckan",
	"field-day-relative+0": "i dag",
	"field-hour": "timme",
	"field-day-relative+1": "i morgon",
	"field-day-relative+2": "i övermorgon",
	"field-day": "dag",
	"field-month-relative+0": "denna månad",
	"field-month-relative+1": "nästa månad",
	"field-dayperiod": "fm/em",
	"field-month": "månad",
	"field-era": "era",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"eraAbbr": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tempyō (729–749)",
		"Tempyō-kampō (749–749)",
		"Tempyō-shōhō (749–757)",
		"Tempyō-hōji (757–765)",
		"Temphō-jingo (765–767)",
		"Jingo-keiun (767–770)",
		"Hōki (770–780)",
		"Ten-ō (781–782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saiko (854–857)",
		"Tennan (857–859)",
		"Jōgan (859–877)",
		"Genkei (877–885)",
		"Ninna (885–889)",
		"Kampyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Shōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten-en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Ei-en (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eiho (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kaho (1094–1096)",
		"Eichō (1096–1097)",
		"Shōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110–1113)",
		"Eikyū (1113–1118)",
		"Gen-ei (1118–1120)",
		"Hoan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hoen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Tenyō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hogen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin-an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryuku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken-ei (1206–1207)",
		"Shōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Shōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tempuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En-ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun-ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun-ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkei (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkyō (1321–1324)",
		"Shōchū (1324–1326)",
		"Kareki (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kemmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun-an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenmon (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genwa (1615–1624)",
		"Kan-ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Shōō (1652–1655)",
		"Meiryaku (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenwa (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan-en (1748–1751)",
		"Hōryaku (1751–1764)",
		"Meiwa (1764–1772)",
		"An-ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man-en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"Meiji",
		"Taishō",
		"Shōwa",
		"Heisei"
	],
	"field-weekday": "veckodag",
	"field-zone": "tidszon"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/sv/japanese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "lördag denna vecka",
	"field-sat-relative+1": "lördag nästa vecka",
	"field-dayperiod": "fm/em",
	"field-sun-relative+-1": "söndag förra veckan",
	"field-mon-relative+-1": "måndag förra veckan",
	"field-minute": "Minut",
	"dateTimeFormat-full": "{1} {0}",
	"field-day-relative+-1": "i går",
	"field-weekday": "Veckodag",
	"field-day-relative+-2": "i förrgår",
	"dateTimeFormat-short": "{1} {0}",
	"field-era": "Era",
	"dateTimeFormat-medium": "{1} {0}",
	"field-hour": "Timme",
	"field-sun-relative+0": "söndag denna vecka",
	"field-sun-relative+1": "söndag nästa vecka",
	"field-wed-relative+-1": "onsdag förra veckan",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgon",
	"eraAbbr": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tempyō (729–749)",
		"Tempyō-kampō (749–749)",
		"Tempyō-shōhō (749–757)",
		"Tempyō-hōji (757–765)",
		"Temphō-jingo (765–767)",
		"Jingo-keiun (767–770)",
		"Hōki (770–780)",
		"Ten-ō (781–782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saiko (854–857)",
		"Tennan (857–859)",
		"Jōgan (859–877)",
		"Genkei (877–885)",
		"Ninna (885–889)",
		"Kampyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Shōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten-en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Ei-en (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eiho (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kaho (1094–1096)",
		"Eichō (1096–1097)",
		"Shōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110–1113)",
		"Eikyū (1113–1118)",
		"Gen-ei (1118–1120)",
		"Hoan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hoen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Tenyō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hogen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin-an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryuku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken-ei (1206–1207)",
		"Shōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Shōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tempuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En-ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun-ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun-ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkei (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkyō (1321–1324)",
		"Shōchū (1324–1326)",
		"Kareki (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kemmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun-an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenmon (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genwa (1615–1624)",
		"Kan-ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Shōō (1652–1655)",
		"Meiryaku (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenwa (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan-en (1748–1751)",
		"Hōryaku (1751–1764)",
		"Meiwa (1764–1772)",
		"An-ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man-en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"Meiji",
		"Taishō",
		"Shōwa",
		"Heisei"
	],
	"field-day-relative+2": "i övermorgon",
	"field-tue-relative+0": "tisdag denna vecka",
	"field-zone": "Tidszon",
	"field-tue-relative+1": "tisdag nästa vecka",
	"field-week-relative+-1": "förra veckan",
	"field-year-relative+0": "i år",
	"field-year-relative+1": "nästa år",
	"field-sat-relative+-1": "lördag förra veckan",
	"field-year-relative+-1": "i fjol",
	"field-year": "År",
	"field-fri-relative+0": "fredag denna vecka",
	"field-fri-relative+1": "fredag nästa vecka",
	"dateTimeFormat-long": "{1} {0}",
	"field-week": "Vecka",
	"field-week-relative+0": "denna vecka",
	"field-week-relative+1": "nästa vecka",
	"field-month-relative+0": "denna månad",
	"field-month": "Månad",
	"field-month-relative+1": "nästa månad",
	"field-fri-relative+-1": "fredag förra veckan",
	"field-second": "Sekund",
	"field-tue-relative+-1": "tisdag förra veckan",
	"field-day": "Dag",
	"field-mon-relative+0": "måndag denna vecka",
	"field-mon-relative+1": "måndag nästa vecka",
	"field-thu-relative+0": "torsdag denna vecka",
	"field-second-relative+0": "nu",
	"field-thu-relative+1": "torsdag nästa vecka",
	"field-wed-relative+0": "onsdag denna vecka",
	"field-wed-relative+1": "onsdag nästa vecka",
	"field-month-relative+-1": "förra månaden",
	"field-thu-relative+-1": "torsdag förra veckan"
}
//end v1.x content
);
